@@ -1205,7 +1205,7 @@ Row<eT>::fixed<fixed_n_elem>::operator=(const subview_cube<eT>& X)
     {
     arma_extra_debug_sigprint();
     
-    const uword N = list.size();
+    const uword N = uword(list.size());
     
     arma_debug_check( (N > fixed_n_elem), "Row::fixed: initialiser list is too long" );
     
@@ -1243,75 +1243,79 @@ Row<eT>::fixed<fixed_n_elem>::operator=(const fixed<fixed_n_elem>& X)
 
 
 
-template<typename eT>
-template<uword fixed_n_elem>
-template<typename T1, typename eop_type>
-inline
-const Row<eT>&
-Row<eT>::fixed<fixed_n_elem>::operator=(const eOp<T1, eop_type>& X)
-  {
-  arma_extra_debug_sigprint();
+#if defined(ARMA_GOOD_COMPILER)
   
-  arma_type_check(( is_same_type< eT, typename T1::elem_type >::no ));
-  
-  const bool bad_alias = (eOp<T1, eop_type>::proxy_type::has_subview  &&  X.P.is_alias(*this));
-  
-  if(bad_alias == false)
+  template<typename eT>
+  template<uword fixed_n_elem>
+  template<typename T1, typename eop_type>
+  inline
+  const Row<eT>&
+  Row<eT>::fixed<fixed_n_elem>::operator=(const eOp<T1, eop_type>& X)
     {
-    arma_debug_assert_same_size(uword(1), fixed_n_elem, X.get_n_rows(), X.get_n_cols(), "Row::fixed::operator=");
+    arma_extra_debug_sigprint();
     
-    eop_type::apply(*this, X);
-    }
-  else
-    {
-    arma_extra_debug_print("bad_alias = true");
+    arma_type_check(( is_same_type< eT, typename T1::elem_type >::no ));
     
-    Row<eT> tmp(X);
+    const bool bad_alias = (eOp<T1, eop_type>::proxy_type::has_subview  &&  X.P.is_alias(*this));
     
-    (*this) = tmp;
+    if(bad_alias == false)
+      {
+      arma_debug_assert_same_size(uword(1), fixed_n_elem, X.get_n_rows(), X.get_n_cols(), "Row::fixed::operator=");
+      
+      eop_type::apply(*this, X);
+      }
+    else
+      {
+      arma_extra_debug_print("bad_alias = true");
+      
+      Row<eT> tmp(X);
+      
+      (*this) = tmp;
+      }
+    
+    return *this;
     }
   
-  return *this;
-  }
-
-
-
-template<typename eT>
-template<uword fixed_n_elem>
-template<typename T1, typename T2, typename eglue_type>
-inline
-const Row<eT>&
-Row<eT>::fixed<fixed_n_elem>::operator=(const eGlue<T1, T2, eglue_type>& X)
-  {
-  arma_extra_debug_sigprint();
   
-  arma_type_check(( is_same_type< eT, typename T1::elem_type >::no ));
-  arma_type_check(( is_same_type< eT, typename T2::elem_type >::no ));
   
-  const bool bad_alias =
-    (
-    (eGlue<T1, T2, eglue_type>::proxy1_type::has_subview  &&  X.P1.is_alias(*this))
-    ||
-    (eGlue<T1, T2, eglue_type>::proxy2_type::has_subview  &&  X.P2.is_alias(*this))
-    );
-  
-  if(bad_alias == false)
+  template<typename eT>
+  template<uword fixed_n_elem>
+  template<typename T1, typename T2, typename eglue_type>
+  inline
+  const Row<eT>&
+  Row<eT>::fixed<fixed_n_elem>::operator=(const eGlue<T1, T2, eglue_type>& X)
     {
-    arma_debug_assert_same_size(uword(1), fixed_n_elem, X.get_n_rows(), X.get_n_cols(), "Row::fixed::operator=");
+    arma_extra_debug_sigprint();
     
-    eglue_type::apply(*this, X);
-    }
-  else
-    {
-    arma_extra_debug_print("bad_alias = true");
+    arma_type_check(( is_same_type< eT, typename T1::elem_type >::no ));
+    arma_type_check(( is_same_type< eT, typename T2::elem_type >::no ));
     
-    Row<eT> tmp(X);
+    const bool bad_alias =
+      (
+      (eGlue<T1, T2, eglue_type>::proxy1_type::has_subview  &&  X.P1.is_alias(*this))
+      ||
+      (eGlue<T1, T2, eglue_type>::proxy2_type::has_subview  &&  X.P2.is_alias(*this))
+      );
     
-    (*this) = tmp;
+    if(bad_alias == false)
+      {
+      arma_debug_assert_same_size(uword(1), fixed_n_elem, X.get_n_rows(), X.get_n_cols(), "Row::fixed::operator=");
+      
+      eglue_type::apply(*this, X);
+      }
+    else
+      {
+      arma_extra_debug_print("bad_alias = true");
+      
+      Row<eT> tmp(X);
+      
+      (*this) = tmp;
+      }
+    
+    return *this;
     }
   
-  return *this;
-  }
+#endif
 
 
 
