@@ -1,35 +1,22 @@
-// Copyright (C) 2010-2012 NICTA (www.nicta.com.au)
-// Copyright (C) 2010-2012 Conrad Sanderson
+// Copyright (C) 2010-2015 Conrad Sanderson
+// Copyright (C) 2010-2015 NICTA (www.nicta.com.au)
 // 
-// This file is part of the Armadillo C++ library.
-// It is provided without any warranty of fitness
-// for any purpose. You can redistribute this file
-// and/or modify it under the terms of the GNU
-// Lesser General Public License (LGPL) as published
-// by the Free Software Foundation, either version 3
-// of the License or (at your option) any later version.
-// (see http://www.opensource.org/licenses for more info)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
 //! \addtogroup op_cumsum
 //! @{
 
 
-template<typename T1>
+template<typename eT>
 inline
 void
-op_cumsum_mat::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_mat>& in)
+op_cumsum_mat::apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
-  
-  const unwrap_check<T1>  tmp(in.m, out);
-  const Mat<eT>&      X = tmp.M;
-  
-  const uword dim = in.aux_uword_a;
-  arma_debug_check( (dim > 1), "cumsum(): incorrect usage. dim must be 0 or 1");
-  
   out.copy_size(X);
   
   const uword X_n_rows = X.n_rows;
@@ -37,7 +24,7 @@ op_cumsum_mat::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_mat
   
   if(dim == 0)
     {
-    arma_extra_debug_print("op_cumsum::apply(), dim = 0");
+    arma_extra_debug_print("op_cumsum_mat::apply(): dim = 0");
     
     for(uword col=0; col<X_n_cols; ++col)
       {
@@ -57,7 +44,7 @@ op_cumsum_mat::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_mat
   else
   if(dim == 1)
     {
-    arma_extra_debug_print("op_cumsum::apply(), dim = 1");
+    arma_extra_debug_print("op_cumsum_mat::apply(): dim = 1");
     
     for(uword row=0; row<X_n_rows; ++row)
       {
@@ -78,14 +65,40 @@ op_cumsum_mat::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_mat
 template<typename T1>
 inline
 void
-op_cumsum_vec::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_vec>& in)
+op_cumsum_mat::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_mat>& in)
   {
   arma_extra_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
-  const unwrap_check<T1>   tmp(in.m, out);
-  const Mat<eT>&       X = tmp.M;
+  const unwrap<T1>   tmp(in.m);
+  const Mat<eT>& X = tmp.M;
+  
+  const uword dim = in.aux_uword_a;
+  arma_debug_check( (dim > 1), "cumsum(): parameter 'dim' must be 0 or 1" );
+  
+  if(&out == &X)
+    {
+    Mat<eT> out2;
+    
+    op_cumsum_mat::apply_noalias(out2, X, dim);
+    
+    out.steal_mem(out2);
+    }
+  else
+    {
+    op_cumsum_mat::apply_noalias(out, X, dim);
+    }
+  }
+
+
+
+template<typename eT>
+inline
+void
+op_cumsum_vec::apply_noalias(Mat<eT>& out, const Mat<eT>& X)
+  {
+  arma_extra_debug_sigprint();
   
   const uword n_elem = X.n_elem;
   
@@ -106,5 +119,35 @@ op_cumsum_vec::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_vec
 
 
 
+
+template<typename T1>
+inline
+void
+op_cumsum_vec::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_vec>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  const quasi_unwrap<T1> U(in.m);
+  
+  const Mat<eT>& X = U.M;
+  
+  if(U.is_alias(out))
+    {
+    Mat<eT> out2;
+    
+    op_cumsum_vec::apply_noalias(out2, X);
+    
+    out.steal_mem(out2);
+    }
+  else
+    {
+    op_cumsum_vec::apply_noalias(out, X);
+    }
+  }
+
+
+
 //! @}
 
